@@ -26,6 +26,8 @@ import { SurveyCompletionNotifierProcessor } from './SurveyCompletionNotifierPro
 import { SyncLookupRefresher } from './SyncLookupRefresher';
 import { GenerateRepeatingTasks } from './GenerateRepeatingTasks';
 import { GenerateRepeatingAppointments } from './GenerateRepeatingAppointments';
+import { GenerateMedicationAdministrationRecords } from './GenerateMedicationAdministrationRecords';
+import { MedicationDiscontinuer } from './MedicationDiscontinuer';
 
 export { startFhirWorkerTasks } from './fhir';
 
@@ -49,6 +51,8 @@ export async function startScheduledTasks(context) {
     SyncLookupRefresher,
     GenerateRepeatingTasks,
     GenerateRepeatingAppointments,
+    GenerateMedicationAdministrationRecords,
+    MedicationDiscontinuer,
     SendStatusToMetaServer,
   ];
 
