@@ -17,4 +17,4 @@ export * from './getLabTestsFromLabRequests';
 export * from './numeralTranslation';
 export * from './enumRegistry';
 export * from './invoice';
-export * from './refreshChildRecordsForSync';
+export * from './medication';
